@@ -21,7 +21,7 @@ def image_to_tensor(image: Image) -> np.ndarray:
     mean = [103.939, 116.779, 123.68]
     image = image.resize((227, 227))
     image = image.convert('RGB')
-    tensor = np.asarray(image)
+    tensor = np.asarray(image, dtype=np.float16)
     tensor = tensor[..., ::-1]
     tensor = tensor - np.array(mean)
     assert tensor.shape == (227, 227, 3)
