@@ -1,6 +1,6 @@
 """Init for utils."""
-from .graph_utils import load_graph, pb_to_tensorboard_event, freeze_session, freeze_graph_from_ckpt
-from .tf_runner import TFRunner
+from .graph_utils import load_graph, pb_to_tensorboard_event, freeze_session, freeze_graph_from_ckpt, wrap_frozen_graph
+from .tf_runner import TFRunner, TFRunnerOld
 from .runner import Runner
 
 __all__ = [
@@ -10,7 +10,9 @@ __all__ = [
     'pb_to_tensorboard_event',
     'freeze_session',
     'freeze_graph_from_ckpt',
+    'wrap_frozen_graph',
     'TFRunner',
+    'TFRunnerOld',
 ]
 
 try:
